@@ -67,6 +67,8 @@ import GroupManager
 import ContactManager
 from AvatarHistory import AvatarHistoryViewer
 
+from SingleInstance import SingleInstance
+
 SERVER_HOST = 'messenger.hotmail.com'
 
 class Controller(gobject.GObject):
@@ -97,12 +99,12 @@ class Controller(gobject.GObject):
             ()),
     }
 
-    def __init__(self, username, minimized, leakdebug, iconified, badroot):
+    def __init__(self, username, minimized, leakdebug, iconified, badroot, singleinstance):
         '''Constructor'''
         gobject.GObject.__init__(self)
 
         self.NAME = 'emesene'
-        self.VERSION = '1.6.2 "chimarrão"'
+        self.VERSION = '1.6.3 - "Uberlândia"'
         self.COPYRIGHT = 'Luis Mariano Guerra, dx, C10uD, arielj'
         self.COMMENT = _('A client for the WLM%s network') % u'\u2122'
         self.LICENSE_FALLBACK = 'GNU General Public License'
@@ -380,9 +382,9 @@ class Controller(gobject.GObject):
         sys.excepthook = self.except_hook_dialog
 
         # FIXME: strange issue with avatars
-        self.changeAvatar(self.config.user['avatarPath'])
+        self.changeAvatar(self.config.user['avatarPath'],initial=True)
         self.mainWindow.buildInterface('userlist')
-        self.changeAvatar(self.config.user['avatarPath'])
+        self.changeAvatar(self.config.user['avatarPath'],initial=True)
         
         layout = self.config.user['conversationLayout']
         if not self.conversationLayoutManager.load(layout):
@@ -702,15 +704,15 @@ class Controller(gobject.GObject):
         currentAvatarPath = self.config.user['avatarPath']
         dialog.show_profile(self, nick, psm, currentAvatarPath, responseProfile)
 
-    def on_change_avatar(self, msnp, filename):
+    def on_change_avatar(self, msnp, filename, initial=False):
         '''control if the avatar already exists or save the new avatar'''
         if os.path.exists(filename):
-            self.changeAvatar(filename)
+            self.changeAvatar(filename, initial)
             return
         else:
             return
 
-    def changeAvatar(self, filename):
+    def changeAvatar(self, filename, initial=False):
         if not self.msn:
             return
 
@@ -719,18 +721,21 @@ class Controller(gobject.GObject):
         try:
             self.avatar = Avatar.Avatar(self, filename,
                 self.config.getAvatarsCachePath())
+            filename = self.avatar.getImagePath()
         except:  # may be GError
             return
 
         if filename == '':
-            self.msn.setDisplayPicture('')
             self.mainWindow.setAvatar(self.theme.getImage('userPanel'))
             self.config.user['avatarPath'] = ''
         else:
-            self.msn.setDisplayPicture(self.avatar.getImagePath())
             self.mainWindow.setAvatar(self.avatar.getThumb())
             self.config.user['avatarPath'] = self.avatar.getImagePath()
 
+        # if not initial, update avatar on Msn's servers
+        if not initial:
+            self.msn.setDisplayPicture(filename)
+
         self.emit('avatar-changed')
 
     def on_self_status_changed(self, msn, status):
@@ -926,24 +931,25 @@ def parseArgs():
     leakdebug = False
     iconified = False
     badroot = False
+    singleinstance = False
 
     # parse arguments
     try:
         import getopt
     except ImportError:
         #getopt is disabled in emesene py2exe
-        return ('', False, False, False)
+        return ('', False, False, False, False, False)
 
-    shortArgs = 'm,i,f'
+    shortArgs = 'm,i,f,s'
     longArgs = ['iconified', 'minimized', 'user=', 'fast-login', 'leakdebug', 
-                'i-know-that-running-emesene-as-root-is-bad']
+                'i-know-that-running-emesene-as-root-is-bad', 'single-instance']
     try:
         args = getopt.getopt(sys.argv[1:], shortArgs, longArgs)
     except getopt.GetoptError, e:
         # wrong input, display usage
         print e
         print 'Usage:', sys.argv[0], '[-m|--minimized] | [-i | --iconified] [--user=mail@address]'
-        print 'Advanced options: [-f|--fast-login], --leakdebug, --i-know-that-running-emesene-as-root-is-bad'
+        print 'Advanced options: [-f|--fast-login], --leakdebug, --i-know-that-running-emesene-as-root-is-bad, [-s|--single-instance]'
         sys.exit(1)
 
     # parse getopt output
@@ -959,8 +965,10 @@ def parseArgs():
             leakdebug = True
         if key == '--i-know-that-running-emesene-as-root-is-bad':
             badroot = True
+        if key == '-s' or key == '--single-instance':
+            singleinstance = True
 
-    return (username, minimized, leakdebug, iconified, badroot)
+    return (username, minimized, leakdebug, iconified, badroot, singleinstance)
 
 def debug(msg):
     '''print a debug message'''
@@ -968,11 +976,20 @@ def debug(msg):
 
 def main():
     args = parseArgs()
+
     if (os.name == 'posix') and (os.getuid() == 0) and (args[4] == False):
         print "I refuse to run as root. " \
               "If you know the risks and still want to do it," \
               " just add the --i-know-that-running-emesene-as-root-is-bad option."
         return
+
+    single_instance = SingleInstance()
+
+    if args[5] and single_instance.is_running():
+        print "Another instance of emesene is already running. Quitting."
+        # try to show instance already running
+        single_instance.show()
+        sys.exit(0)
     
     if (os.name != 'nt'):
         try:
