@@ -483,7 +483,7 @@ class Conversation(gobject.GObject):
             self.reconnect()
             self.switchboard.sendNudge()
 
-        self.appendOutputText(None, _("you have sent a nudge!"), 'information')
+        self.appendOutputText(None, _("You have sent a nudge!"), 'information')
 
     def reconnect(self):
         '''reconnect the switchboard'''
