@@ -170,10 +170,7 @@ class ConversationLayoutManager(object):
             messageDataObject.setConversation(conversation)
             messageDataObject.setUser(username)
 
-            if self.config.user['parseSmilies']:
-                message = messageDataObject.get()
-            else:
-                message = messageDataObject.get(smileys=False)
+            message = messageDataObject.get(smileys=self.config.user['parseSmilies'])
 
             message = message.replace('\n', '<br/>')
         else:
@@ -186,10 +183,15 @@ class ConversationLayoutManager(object):
 
         # Fills nick
         arguments['nick'] = ''
-        if username and p4c:
-            arguments['nick'] = username
-        elif username:
-            arguments['nick'] = self.controller.msn.getUserDisplayName(username)
+        if username:
+            if username.find("@") == -1: #if it's not an email
+                arguments['nick'] = username
+            else: #may catch nicknames with the char "@"
+                arguments['nick'] = self.controller.msn.getUserDisplayName(username)
+
+        # prevent lowercasing nick when an oim is received
+        #if type == 'offline_incoming' and username.find("@") != -1:
+        #    arguments['nick'] = username
 
         # Fills email
         arguments['email'] = username
@@ -325,10 +327,7 @@ class LayoutTagParser:
             nick = self.arguments['nick']
 
             nickDataObject = self.unifiedParser.getParser(nick, ConversationDataType)
-            if self.config.user['parseSmilies']:
-                nick = nickDataObject.get(urls=False)
-            else:
-                nick = nickDataObject.get(urls=False, smileys=False)
+            nick = nickDataObject.get(urls=False, smileys=self.config.user['parseSmilies'])
 
             return nick
 
