@@ -163,14 +163,14 @@ class ConversationUI(gtk.VBox):
         else:
             self.hbox.pack_start(self.remoteAvatar, False, False, padding = 1)
             self.hbox.pack_start(self.mainPaned, True, True)
-        
+        self.hbox.set_size_request(-1,40)
         self.hbox.show()
 
         # the vertical panel that divides the textview and the input
         # (toolbar and input)
         vpaned = gtk.VPaned()
-        vpaned.pack1(self.hbox, True, True)
-        vpaned.pack2(self.input, False)
+        vpaned.pack1(self.hbox, True, False)
+        vpaned.pack2(self.input, False, True)
         # connect the notify signal to catch dragging of the seperator, as
         # suggested in http://faq.pygtk.org/index.py?req=show&file=faq19.013.htp
         vpaned.connect('notify', self.onInputResize)
