@@ -27,6 +27,10 @@ class GroupMenu(gtk.Menu):
         gtk.Menu.__init__(self)
 
         self.controller = controller
+        self.group = group
+
+        someoneBlocked = False
+        someoneUnblocked = False
 
         addGroupMenuItem = self.newImageMenuItem\
                     (_('Add _group...'), gtk.STOCK_ADD)
@@ -41,12 +45,23 @@ class GroupMenu(gtk.Menu):
 
             self.add(gtk.SeparatorMenuItem())
 
-            blockGroupMenuItem = self.newImageMenuItem\
+            for email, user in self.group.users.items():
+                if not user.blocked and not someoneUnblocked:
+                    blockGroupMenuItem = self.newImageMenuItem\
                         (_('Block group'), gtk.STOCK_STOP)
-            self.add(blockGroupMenuItem)
-            unblockGroupMenuItem = self.newImageMenuItem\
+                    self.add(blockGroupMenuItem)
+                    blockGroupMenuItem.connect('activate', self.on_block_group_activate)
+                    someoneUnblocked = True
+
+                elif user.blocked and not someoneBlocked:
+                    unblockGroupMenuItem = self.newImageMenuItem\
                         (_('Unblock group'), gtk.STOCK_APPLY)
-            self.add(unblockGroupMenuItem)
+                    self.add(unblockGroupMenuItem)
+                    unblockGroupMenuItem.connect('activate', self.on_unblock_group_activate)
+                    someoneBlocked = True
+
+                elif someoneBlocked and someoneUnblocked:
+                    break
 
             self.add(gtk.SeparatorMenuItem())
 
@@ -56,13 +71,9 @@ class GroupMenu(gtk.Menu):
 
             deleteGroupMenuItem.connect('activate', self.on_delete_group_activate)
             renameGroupMenuItem.connect('activate', self.on_rename_group_activate)
-            blockGroupMenuItem.connect('activate', self.on_block_group_activate)
-            unblockGroupMenuItem.connect('activate', self.on_unblock_group_activate)
 
         self.show_all()
 
-        self.group = group
-
     def newImageMenuItem(self, label, stock = None, img = None):
         mi = gtk.ImageMenuItem(_(label))
 
@@ -87,15 +98,11 @@ class GroupMenu(gtk.Menu):
         self.controller.groups.rename_dialog(self.group.name)
 
     def on_block_group_activate(self, *args):
-        groupDict = self.controller.msn.contactManager.groups
-        selectedGroup = groupDict[self.group.id]
-        for email, user in selectedGroup.users.items():
+        for email, user in self.group.users.items():
             if not user.blocked:
                 self.controller.contacts.block(email)
 
     def on_unblock_group_activate(self, *args):
-        groupDict = self.controller.msn.contactManager.groups
-        selectedGroup = groupDict[self.group.id]
-        for email, user in selectedGroup.users.items():
+        for email, user in self.group.users.items():
             if user.blocked:
                 self.controller.contacts.unblock(email)
