@@ -118,10 +118,7 @@ class Login(gtk.VBox):
         self.tStatus.set_active(0)
 
         pixbuf = self.controller.theme.getImage('login', False)
-        if (os.name == 'nt'):
-            self.loginImage = gtk.Image()
-        else:
-            self.loginImage = Widgets.avatarHolder()
+        self.loginImage = Widgets.avatarHolder()
         self.loginImage.set_from_pixbuf(pixbuf)
         if not self.controller.config.glob['dontShowAvatarInLoginWindow']:
             self.pack_start(self.loginImage , True , False)
@@ -184,12 +181,18 @@ class Login(gtk.VBox):
             self.cAutoLogin = gtk.CheckButton(_('Auto-Login'), True)
             self.cAutoLogin.connect('toggled' , self.on_cAutoLogin_toggled)
 
-            if self.controller.config.glob['rememberMe']:
+            #this fixes a bug with user config
+            current_user = self.controller.config.getCurrentUser()
+
+            if self.controller.config.glob['rememberMe'] and current_user != '':
                 self.cRemember.set_active(True)
 
-            if self.controller.config.glob['rememberMyPassword']:
+            if self.controller.config.glob['rememberMyPassword'] and current_user != '':
                 self.cRememberPass.set_active(True)
 
+            if self.controller.config.glob['autoLogin'] and current_user != '':
+                self.cAutoLogin.set_active(True)
+
             self.checkBox = gtk.VBox(spacing=4)
 
             rememberBox = gtk.HBox(spacing=4)
@@ -334,11 +337,12 @@ class Login(gtk.VBox):
                 self.lReconnectCounter.set_text(_('Reconnecting...'))
 
     def login(self):
+        if self._control_fields():
+            return
         self.controller.login(self.getUser() , self.getPass() , self.getStatus())
 
     def bLogin_clicked(self , *args):
-        if self.getUser() == '' or self.getPass() == '' or self.getStatus() == '':
-            self.parent.parent.showNiceBar(_("User or password empty"), self.controller.niceBarWarningColor, gtk.STOCK_DIALOG_WARNING)
+        if self._control_fields():
             return
 
         if self.currentInterface == 'login' and self.cRemember.get_active():
@@ -351,6 +355,15 @@ class Login(gtk.VBox):
 
         self.users.save()
         self.login()
+ 
+    def _control_fields(self):
+        '''control that all login fields are not empty'''
+        if self.getUser() == '' or self.getPass() == '' or self.getStatus() == '':
+            self.controller.mainWindow.showNiceBar(_("User or password empty"),
+                      self.controller.niceBarWarningColor, gtk.STOCK_DIALOG_WARNING)     
+            return True
+        else:
+            return False
 
     def getUser(self):
         self.active_user = self.tUser.get_active()
@@ -358,7 +371,7 @@ class Login(gtk.VBox):
         return self.tUser.get_active_text()
 
     def getPass(self):
-        return self.tPass.get_text()
+        return self.tPass.get_text()[:16]
 
     def getStatus(self):
         return self.statusListStore.get(self.tStatus.get_active_iter(), 1)[0]
