@@ -401,7 +401,11 @@ class MainMenu(gtk.MenuBar):
             filter.add_pattern('*')
             chooser.set_current_name(_('myContacts'))
         chooser.add_filter(filter)
-        chooser.set_current_folder(os.environ['HOME'])
+        if os.name != "nt":
+            folder = os.environ['HOME']
+        else:
+            folder = os.environ['HOMEPATH']
+        chooser.set_current_folder(folder)
         response = chooser.run()
         if response == gtk.RESPONSE_OK:
             all_contacts = self.controller.contacts.get_all_contacts()
@@ -629,5 +633,5 @@ class MainMenu(gtk.MenuBar):
             self.controller.preference_open = True
 
     def on_get_live_activate(self, *args):
-        link = 'https://accountservices.passport.net/reg.srf?sl=1'
+        link = 'https://signup.live.com/signup.aspx'
         desktop.open(link)
