@@ -49,11 +49,9 @@ class PluginManager( object ):
         # we do the import here because we need to wait until the
         # config creates the plugin directory on the user home
         userPlugins = {}
-        if os.name == 'posix' or os.name == 'nt':
-            sys.path.append(paths.CONFIG_DIR)
-            userPlugins = self.inspectPackage(paths.CONFIG_DIR, 
-                    paths.PLUGINS_HOME)
-            
+        sys.path.append(paths.CONFIG_DIR)
+        userPlugins = self.inspectPackage(paths.CONFIG_DIR, paths.PLUGINS_HOME)
+
         systemPlugins = self.inspectPackage(paths.APP_PATH, 
                 paths.PLUGINS_SYSTEM_WIDE)
         
