@@ -105,6 +105,7 @@ class SmilieWindow(gtk.Window):
         self.connect('delete-event', self.on_delete_event)
         self.connect('leave-notify-event', self.on_leave_notify_event)
         self.connect('enter-notify-event', self.on_enter_notify_event)
+        self.connect('key-press-event', self.on_key_press)
 
         self.tag = None
 
@@ -124,26 +125,30 @@ class SmilieWindow(gtk.Window):
         self.closed = True
         return True
 
+    def on_key_press(self, widget, event):
+        if gtk.keysyms.Escape == event.keyval:
+            self.hide()
+
     def clicked(self, button, smilie):
         self.hide()
         self.callback(smilie)
 
     def event(self, button, event, smilie):
-        if event.type == gtk.gdk.BUTTON_PRESS and event.button == 1:
-            self.hide()
-            self.callback(smilie)
         if event.type == gtk.gdk.BUTTON_PRESS and event.button == 3:
 
             # -- Custom Emoticon Menu --
             self.emoMenu = gtk.Menu()
+            self.emoMenu.connect('enter-notify-event', self.on_enter_notify_event)
 
             self.shortcutItem = gtk.ImageMenuItem(_("Change shortcut"))
+            self.shortcutItem.connect('enter-notify-event', self.on_enter_notify_event)
             self.shortcutItem.set_image(gtk.image_new_from_stock(
                 gtk.STOCK_EDIT, gtk.ICON_SIZE_MENU))
             self.shortcutItem.connect("activate", self.onEditShortcut,
                 smilie)
 
             self.deleteItem = gtk.ImageMenuItem(_("Delete"))
+            self.deleteItem.connect('enter-notify-event', self.on_enter_notify_event)
             self.deleteItem.set_image(gtk.image_new_from_stock(
                 gtk.STOCK_DELETE, gtk.ICON_SIZE_MENU))
             self.deleteItem.connect("activate", self.onDeleteEmo, smilie)
@@ -231,6 +236,7 @@ class SmilieWindow(gtk.Window):
                 smilieImage = gtk.Image()
                 smilieImage.set_from_pixbuf(pixbuf)
                 button.set_image(smilieImage)
+                button.connect('clicked', self.clicked, shortcut)
                 button.connect('event', self.event, shortcut)
                 button.connect('enter-notify-event', self.on_enter_notify_event)
                 self.ceTable.attach(button, x, x+1, y, y+1,False)
