@@ -63,9 +63,9 @@ class StatusMenu(gtk.Menu):
 
     def activate(self, menuitem, status):
         '''change the status with the userparam'''
-        self.controller.contacts.set_status(status)
+        self.controller.msn.changeStatus(status)
 
     def activateNT(self, menuitem, event, status):
         '''change the status with the userparam, ugly windows hack'''
-        self.controller.contacts.set_status(status)
+        self.controller.msn.changeStatus(status)
 
