@@ -326,7 +326,7 @@ class Theme(BaseTheme):
         self.getSmileysList = self.smilies.getSmileysList
         self.getSingleSmileysList = self.smilies.getSingleSmileysList
     
-    def statusToPixbuf(self, status):
+    def statusToPixbuf(self, status, returnPix=True):
         '''Translates a status code in a pixbuf returning the according
         theme image'''
         
@@ -355,6 +355,12 @@ class Theme(BaseTheme):
         elif status == 'LOG' or status == 'login':
             name = 'trayicon2'
 
+        if returnPix:
+            return self.returnPixbuf(name)
+
+        return name
+
+    def returnPixbuf(self, name):
         if name:
             return self.getImage(name)
         else:
