@@ -24,8 +24,6 @@ import time
 import gtk
 import gobject
 
-import time
-
 import emesenelib.common
 import desktop
 
@@ -85,6 +83,7 @@ class Webcam:
         self.win = gtk.Window()
         self.win.set_double_buffered(False)
         self.win.set_app_paintable(True)
+        self.win.set_opacity(1)
         #self.win.set_resizable(False)
         self.win.set_title(_("%s\'s webcam") % self.sender);
         self.win.add(self.image)
@@ -98,6 +97,7 @@ class Webcam:
         self.daarea = gtk.DrawingArea()
         self.daarea.set_colormap(gtk.gdk.colormap_get_system())
         self.win_send = gtk.Window()
+        self.win_send.set_opacity(1)
         self.win_send.set_double_buffered(False)
         self.win_send.set_app_paintable(True)
         #self.win_send.set_resizable(False)
