@@ -1525,9 +1525,11 @@ class CEChooser(ImageChooser):
         self.vbox.pack_start(hbox0, False)
         hbox0.show_all()
 
-        self.shortcut.connect('changed', self._on_changed)
-
         self.smilie_list = smilie_list
+        pygtk_v = gtk.pygtk_version
+        if (pygtk_v[0] == 2 and pygtk_v[1] > 15) or (pygtk_v[0] > 2):
+            self._on_changed(None)
+            self.shortcut.connect('changed', self._on_changed)
 
     def _on_accept(self, button):
         '''method called when the user clicks the button'''
@@ -1579,7 +1581,7 @@ class CEChooser(ImageChooser):
 
         SHORTCUT = self.shortcut.get_text()
 
-        if SHORTCUT in self.smilie_list:
+        if SHORTCUT in self.smilie_list or SHORTCUT == "":
             self.shortcut.set_property('secondary-icon-stock', gtk.STOCK_DIALOG_ERROR)
         else:
             self.shortcut.set_property('secondary-icon-stock', None)
