@@ -389,13 +389,7 @@ class ContactList(object):
             return self.contacts[email].id
         else:
             return ''
-            
-    def getContactPendingId(self, email):
-        email = email.lower()
-        #TODO: where the fuck do i get the contactid (guid)? kthxbai
-        # i can't find where the fucking pendingcontacts are handled
-        return 0    
-        
+
     def getContactGroupIds(self, email):
         '''return a list with the group ids or an empty list'''
         email = email.lower()
@@ -484,7 +478,6 @@ class ContactList(object):
             self.contacts[email.lower()].reverse = (email in self.lists['Reverse'])
             self.contacts[email.lower()].allow = (email in self.lists['Allow'])
             self.contacts[email.lower()].blocked = (email in self.lists['Block'])
-            #self.contacts[email.lower()].pending = (email in self.lists['Pending'])
 
     def getADL(self):
         '''Create a XML String with all the contacts we have for
