@@ -23,6 +23,8 @@ import os
 import httplib
 import socket
 import tempfile
+import datetime
+import time
 
 import ContactData
 import soap.manager
@@ -87,6 +89,7 @@ class ProfileManager(gobject.GObject):
         gobject.GObject.__init__(self)
         self.config = config
         self.profile_retrieved = False
+        self.rid = ""
 
     def onGetMembershipList(self, response):
         '''method called when we receive the membership list'''
@@ -126,6 +129,9 @@ class ProfileManager(gobject.GObject):
                 soap.requests.create_profile(self.proxy, self.reRequestProfile)
             return
 
+        expression_profile = response.body.split('</ExpressionProfile>')[0].split('<ExpressionProfile>')[1]
+        self.rid = expression_profile.split('</ResourceID>')[0].split('<ResourceID>')[1]
+
         try:
             nick = response.body.split('</DisplayName>')[0].split('<DisplayName>')[1]
             nick = common.unescape(nick)
@@ -136,43 +142,93 @@ class ProfileManager(gobject.GObject):
             pm = response.body.split('</PersonalStatus>')[0].split('<PersonalStatus>')[1]
             pm = common.unescape(pm)
         except: 
-            pm = ''        
-            
+            pm = ''
+
         try:
-            dpurl = response.body.split('</StaticUserTilePublicURL>')[0].split('<StaticUserTilePublicURL>')[1]
-            photo = response.body.split('</Photo>')[0].split('<Photo>')[1]
+            dpurl = response.body.split('</PreAuthURL>')[0].split('<PreAuthURL>')[1]
+        except:
+            try:
+                dpurl = response.body.split('</StaticUserTilePublicURL>')[0].split('<StaticUserTilePublicURL>')[1]
+            except:
+                dpurl = ""
+
+        photo = response.body.split('</Photo>')[0].split('<Photo>')[1]
+        try:
             self.dpid = photo.split('</ResourceID>')[0].split('<ResourceID>')[1]
-            name = photo.split('</Name>')[0].split('Name>')[1]
         except:
-            dpurl = ''
             self.dpid = ''
 
-        if dpurl != '' and name != self.config.glob['Id']:         
+        try:
+            modified = (photo.split('</DateModified>')[0].split('<DateModified>')[1])[0:19]
+        except:
+            modified = ''
+
+        newAvatar = True
+        # compare last avatar date and server avatar date, we can't know
+        # the exact time saved on the server, it's something between the
+        # time that we sent the request and the time the response arrived
+        # that's why I compare with seconds of difference (10 is arbitrary)
+        if modified != '':
+            serverDate = modified
+            savedDate = self.config.user['avatarDate']
+
+            try:
+                date1 =  datetime.datetime(int(serverDate[0:4]), \
+                         int(serverDate[5:7]), int(serverDate[8:10]), \
+                         int(serverDate[11:13]), int(serverDate[14:16]), \
+                         int(serverDate[17:19]),0,None)
+                date2 =  datetime.datetime(int(savedDate[0:4]), \
+                         int(savedDate[5:7]), int(savedDate[8:10]), \
+                         int(savedDate[11:13]), int(savedDate[14:16]), \
+                         int(savedDate[17:19]),0,None)
+
+                delta = 0
+                if date2 > date1:
+                    delta = date2 - date1
+                else:
+                    delta = date1 - date2
+                newAvatar = (delta.seconds > 10 or delta.seconds < -10)
+            except:
+                newAvatar = True
+
+        if dpurl != '' and newAvatar:
+            self.config.user['avatarDate'] = modified
             gobject.idle_add(self.getPicture, dpurl)
 
         self.changeNick(nick, initial=True)
         self.changePersonalMessage(pm)
+
+        #it seems these are not on the response anymore
         try:
             self.affinityCache = response.body.split('</CacheKey>')[0].split('<CacheKey>')[1]
         except:
             self.affinityCache = ''
-        expression_profile = response.body.split('</ExpressionProfile>')[0].split('<ExpressionProfile>')[1]
-        self.rid = expression_profile.split('</ResourceID>')[0].split('<ResourceID>')[1]
+        try:
+            name = photo.split('</Name>')[0].split('<Name>')[1]
+        except:
+            name = ''
+
         self.profile_retrieved = True
     
     def updateDisplayPicture(self):
-        if self.affinityCache != '':
-            if self.dpid != '':
-                soap.requests.delete_relationship1(self.proxy, self.affinityCache, \
-                    self.dpid, self.cid, self.onDeleteRelationship1)
-            else:
-                soap.requests.update_dp(self.proxy, self.affinityCache, \
-                    self.cid, self.config.glob['Id'], 'png', \
-                    base64.b64encode(self.msnobj.data), self.onCreateRelationships)
+        #if self.affinityCache != '':
+        if self.dpid != '':
+            soap.requests.delete_relationship1(self.proxy, self.affinityCache, \
+                self.dpid, self.cid, self.onDeleteRelationship1)
+        else:
+            soap.requests.update_dp(self.proxy, self.affinityCache, \
+                self.cid, self.config.glob['Id'], 'png', \
+                base64.b64encode(self.msnobj.data), self.onCreateRelationships)
 
     def getPicture(self, url):
         hdrs = {"User-Agent": "MSN Explorer/9.0 (MSN 8.0; TmstmpExt)",}
-        
+
+        if not url.startswith("http://"):
+            url = "http://byfiles.storage.msn.com/"+url
+        index = url.find("msn.com")
+        #remove "http://" and everything after msn.com
+        server = url[7:index+7]
+
         if self.proxy and self.proxy.host != '':
             proxy_connect = 'CONNECT %s:%s HTTP/1.0\r\n'%(self.proxy.host, self.proxy.port)
             user_agent = 'User-Agent: python\r\n'
@@ -190,16 +246,15 @@ class ProfileManager(gobject.GObject):
             proxy.sendall(proxy_pieces)
             response = proxy.recv(8192) 
             status=response.split()[1]
-            if status!=str(200):  
+            if status!=str(200):
                 raise ValueError,'Error status=%s' % str(status)
                 return False
-            
-            conn = httplib.HTTPConnection('byfiles.storage.msn.com', 80)
+            conn = httplib.HTTPConnection(server, 80)
             conn.sock = proxy
         else:
-            conn = httplib.HTTPConnection('byfiles.storage.msn.com', 80)
+            conn = httplib.HTTPConnection(server, 80)
         try:
-            conn.request("GET", 'http://byfiles.storage.msn.com'+url, headers=hdrs)
+            conn.request("GET", url, headers=hdrs)
             response = conn.getresponse()
         except:
             return
@@ -208,12 +263,15 @@ class ProfileManager(gobject.GObject):
         
         if stat != 200:
             # YouFail
+            print "failed to download avatar"
+            print "reason: ", reas
             return False
         data = response.read()
         #print "DP:", len(data), stat, reas
         fd, fn = tempfile.mkstemp(prefix='emsnpic')
         os.write(fd, data)
-        self.emit('self-dp-changed', fn)
+        initial = True
+        self.emit('self-dp-changed', fn, initial)
         
         return False
  
@@ -245,8 +303,44 @@ class ProfileManager(gobject.GObject):
                 self.onCreateRelationships)
 
     def onCreateRelationships(self,response):
-        #print 'onCreate:'+str(response)
+        #print 'onCreate:'#+str(response)
+        #print response.body
         if response.status[0] == 200:
+
+            # save avatar update time stamp
+            aux1 = time.gmtime()
+            date = datetime.datetime(aux1[0], aux1[1], aux1[2], aux1[3], \
+                              aux1[4], aux1[5])
+
+            # it looks like msn server's are gmt -7                              
+            delta = datetime.timedelta(hours=-7)
+            date = date + delta
+
+            # make one-digit numbers start with "0"
+            year = str(date.year)
+            if date.month < 10:
+                month = "".join(("0",str(date.month)))
+            else:
+                month = str(date.month)
+            if date.day < 10:
+                day = "".join(("0",str(date.day)))
+            else:
+                day = str(date.day)
+            if date.hour < 10:
+                hour = "".join(("0",str(date.hour)))
+            else:
+                hour = str(date.hour)
+            if date.minute < 10:
+                minutes = "".join(("0",str(date.minute)))
+            else:
+                minutes = str(date.minute)
+            if date.second < 10:
+                seconds = "".join(("0",str(date.second)))
+            else:
+                seconds = str(date.second)
+
+            self.config.user['avatarDate'] = "".join((year,"-",month,"-",day,"T",hour,":",minutes,":",seconds))
+
             try:
                 document_rid = response.body.split('</CreateDocumentResult>')[0].split('<CreateDocumentResult>')[1]
                 soap.requests.create_relationships(self.proxy, self.affinityCache, self.rid, \
@@ -678,10 +772,11 @@ class ProfileManager(gobject.GObject):
 
         self.socket.sendCommand("PRP", "MFN " + urllib.quote(nick))
 
-        if not initial and self.affinityCache != '':
-            soap.requests.update_profile(self.proxy, self.affinityCache, \
-                self.rid, common.escape(nick), \
-                common.escape(self.personalMessage), self.onNickChanged, oldNick)
+        if not initial:
+            if self.rid != "":# self.affinityCache != '':
+                soap.requests.update_profile(self.proxy, self.affinityCache, \
+                    self.rid, common.escape(nick), \
+                    common.escape(self.personalMessage), self.onNickChanged, oldNick)
 
     def changeAlias(self, user, alias):
         alias = alias.decode('utf-8', 'replace').encode('utf-8')
@@ -738,10 +833,10 @@ class ProfileManager(gobject.GObject):
             oldPm = self.personalMessage
             self.personalMessage = pm
             self.updateUUX()
-            if self.affinityCache != '':
-                soap.requests.update_profile(self.proxy, self.affinityCache, \
-                    self.rid, common.escape(self.nick), \
-                    common.escape(self.personalMessage), self.onPmChanged, oldPm)
+            #if self.affinityCache != '':
+            soap.requests.update_profile(self.proxy, self.affinityCache, \
+                self.rid, common.escape(self.nick), \
+                common.escape(self.personalMessage), self.onPmChanged, oldPm)
             self.emit('self-personal-message-changed', self.user, pm)
         else:
             common.debug("duplicate pm")
