@@ -315,7 +315,9 @@ class SocketThread(BaseThread):
                     return
                 else:
                     try:
-                        self.socket.send(input_)
+                        sent = self.socket.send(input_)
+                        if sent == 0:
+                            self.signal('hangup')
                     except socket.error:
                         self.signal('hangup')
                         return
