@@ -18,10 +18,7 @@
 
 import os
 import time
-import uuid
-import base64
 import urllib
-import random
 import gobject
 
 import Msnobj
@@ -30,6 +27,8 @@ import p2p.transfers
 
 import common
 
+EMESENE_ACK_CHECK_MSECS = 30000
+
 class Switchboard(gobject.GObject):
     '''This class represents a switchboard connection and provides methods
     and signals to interact with it'''
@@ -144,8 +143,11 @@ class Switchboard(gobject.GObject):
         self.firstUser = ''
 
         self.error = 0
+        # needed for logger
         self.started = time.time()
         
+        # if True, conversation will overwrite sender's nicks 
+        # with p4 context, if available
         self.canUseP4 = msn.canUseP4
         
     def __repr__(self):
@@ -190,7 +192,6 @@ class Switchboard(gobject.GObject):
         
     def leaveChat(self):
         '''leave the conversation'''
-        
         self.setStatus('closed')
         try:
             self.socket.send('OUT\r\n')
@@ -361,7 +362,7 @@ class Switchboard(gobject.GObject):
             self.emit('user-join', mail.lower())
                 
             self.setStatus('established') 
-                
+            
         elif command == 'JOI':
             # JOI god@gmail.com urlencoded%20nick 1615642660\r\n
             (nick, clientID) = params.split()[:2] # likely to break..
@@ -383,22 +384,28 @@ class Switchboard(gobject.GObject):
             # from the other side.
             if params == '1' or wasGroupChat:
                 self.emit('user-leave', tid)
+                
         elif command == 'ACK':
             self.msg_count -= 1
             if int(tid) in self.outDict:
                 del self.outDict[int(tid)]
                 #print "deleted ", tid, " have left:", self.outDict 
-                
+            return False
         elif command == 'NAK': #untested, never had any of this.
             self.msg_count -= 1
             if int(tid) in self.outDict:
                 msg = self.outDict[int(tid)]
-                self.check_outDict(tid)    
+                self.check_outDict(tid)   
+            return False 
         try:
             self.error = int(command)
             if len(self.members) == 0:
                 close('server error %d, closing switchboard' % self.error, \
                     'error')
+                self.setStatus('error')
+                # flush message in queue as oims
+                for mess in self.messageQueue:
+                    self.msn.msnOIM.send(self.firstUser, mess['msg'])
                 return False
         except ValueError:
             pass
@@ -412,7 +419,7 @@ class Switchboard(gobject.GObject):
         if ctype == 'text/plain; charset=UTF-8' or ctype == 'text/x-msnmsgr-datacast':
             # crappy sendPayloadCommand returns ++tid so...
             self.outDict[int(tid) - 1] = msg
-            gobject.timeout_add(15000, self.check_outDict, int(tid) - 1)
+            gobject.timeout_add(EMESENE_ACK_CHECK_MSECS, self.check_outDict, int(tid) - 1)
             #print "added number", tid - 1
     
     def check_outDict(self, tid, dontClose=0):
@@ -545,7 +552,7 @@ class Switchboard(gobject.GObject):
                 'acknowledgeType': acknowledgeType, \
                 'contentType': contentType \
             })
-            
+
         elif self.status == 'established':
             try:
                 tid = self.socket.sendPayloadCommand('MSG', acknowledgeType, \
@@ -559,6 +566,10 @@ class Switchboard(gobject.GObject):
                     'switchboard')
                 common.debug(str(e), 'switchboard')
                 self.setStatus('closed')
+        
+    def sendKeepAlive(self):
+        ''' sends a keepalive to current switchboard '''
+        self.sendMessage('', '', 'text/x-keep-alive', 'A')            
 
     def flushMessageQueue(self):
         '''send all the unsended messages'''
