@@ -115,8 +115,10 @@ class Msnp(ProfileManager.ProfileManager):
             (gobject.TYPE_STRING,gobject.TYPE_STRING)),
         'self-current-media-changed' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
             (gobject.TYPE_STRING,gobject.TYPE_STRING,gobject.TYPE_PYOBJECT)),
+        # the filename of the new avatar and a boolean indication if it's changed
+        # after retrieving it from Msn's server (True) or set by the user (False)
         'self-dp-changed' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
-            (gobject.TYPE_STRING,)),
+            (gobject.TYPE_STRING,gobject.TYPE_BOOLEAN)),
 
         'new-conversation' : (gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE,
             (gobject.TYPE_STRING,gobject.TYPE_PYOBJECT)),
@@ -271,7 +273,6 @@ class Msnp(ProfileManager.ProfileManager):
         self._allowedRedirects = 5
         self._onLogin = False
         self.canUseP4 = canUseP4
-    
     # login() calls _redirect(), which calls loginInputHandler on socket input,
     # which calls loginProcess
 
@@ -486,8 +487,17 @@ class Msnp(ProfileManager.ProfileManager):
 
         # change the nickname
         self.changeNick(self.nick, initial=True)
+        gobject.timeout_add(10000, self.enable_notifications)
         soap.requests.get_profile(self.proxy, self.cid, self.onGetProfile)
 
+    # a delay in case the UUX command doesn't enable notifications
+    # see "processCommand()" method
+    def enable_notifications(self):
+        if not self.canNotify:
+            self.emit('enable-notifications')
+            self.canNotify = True
+        return False
+
     def passportReAuth(self, hash=None):
         if hash == None:
             hash = self.hash
@@ -763,9 +773,8 @@ class Msnp(ProfileManager.ProfileManager):
             # have something to do with this, but this seems safer
             self.accountConfirmed = False
             self.emit('account-unconfirmed')
-        elif command == "PRP" and self.profile_retrieved and not self.canNotify:
-            self.emit('enable-notifications')
-            self.canNotify = True
+        elif command == "UUX" and params == "0" and self.profile_retrieved:
+            self.enable_notifications()
 
     def parseUBX(self, command, tid, params, payload):
         '''this function parses the UBX payload, and sets the personal
