@@ -25,6 +25,10 @@ import httplib
 import string
 import base64
 import socket
+import os
+
+# gzipped requests ftw!
+import StringIO, gzip
 
 HAVE_PY25 = 0
 if sys.version_info[1] > 5:
@@ -199,6 +203,7 @@ class SoapManager( threading.Thread ):
             "User-Agent": "MSN Explorer/9.0 (MSN 8.0; TmstmpExt)",
             "Connection": "Keep-Alive",
             "Cache-Control": "no-cache",
+            "Accept-encoding": "gzip", # highly improves bandwidth usage
         }
         
 
@@ -223,7 +228,7 @@ class SoapManager( threading.Thread ):
             proxy.sendall(proxy_pieces)
             response = proxy.recv(8192) 
             status=response.split()[1]
-            if status!=str(200):  raise 'Error status=',str(status)
+            if status!=str(200):  raise ValueError,'Error status=%s' % str(status)
             # trivial setup for ssl socket
             if HAVE_PY25:
                 sslconn = socket.ssl(proxy, None, None)
@@ -238,12 +243,31 @@ class SoapManager( threading.Thread ):
             else:
                 conn = httplib.HTTPConnection(soapRequest.host, soapRequest.port)
             
+        if soapRequest.action == 'http://www.msn.com/webservices/storage/w10/CreateDocument' or \
+            soapRequest.action == 'http://www.msn.com/webservices/storage/w10/DeleteRelationships':
+            #print soapRequest.path, soapRequest.body, headers
+            if os.name == "nt":
+                tempfile = os.environ['TEMP'] + os.sep + "createdocumentsoap.txt"
+                tempfile = unicode(tempfile)
+            else:
+                tempfile = '/tmp/createdocumentsoap.txt'
+            f = open(tempfile, 'w')
+            f.write(soapRequest.body)
+            f.close()
         conn.request("POST", soapRequest.path, soapRequest.body, headers)
         response = conn.getresponse()
             
+        data = response.read()
+        isGzipd = response.getheader('Content-Encoding', '')
+        if isGzipd == 'gzip':
+            # data is gzipped, unzipit!
+            cstream = StringIO.StringIO(data)
+            gzpr = gzip.GzipFile(fileobj=cstream)
+            data = gzpr.read()
+            
         soapResponse = SoapRequest(soapRequest.proxy, soapRequest.action,
             soapRequest.host, soapRequest.port, soapRequest.path,
-            response.read(), soapRequest.callback, soapRequest.args)
+            data, soapRequest.callback, soapRequest.args)
     
         soapResponse.status = (response.status, response.reason)
         if soapResponse.body.count('TweenerChallenge') or \
@@ -254,5 +278,4 @@ class SoapManager( threading.Thread ):
                      soapResponse.body.count('PassportAuthFail'):
             self.msn.passportReAuth()
             soapResponse = self.makeSoapRequest(soapRequest, False)
-        
         return soapResponse
