@@ -667,9 +667,7 @@ class HtmlTextView(gtk.TextView):
         self._changed_cursor = False
         self.linkColor = "#0000FF"
 
-        self.connect('copy-clipboard', self._on_copy_clipboard)
-        self.clipboard = gtk.Clipboard(selection=gtk.gdk.atom_intern("CLIPBOARD"))
-        self.get_buffer().add_selection_clipboard(self.clipboard)
+        self.connect_after('copy-clipboard', self._on_copy_clipboard)
         self.emotes = {}
 
         self.connect("motion-notify-event", self.__motion_notify_event)
@@ -885,8 +883,9 @@ class HtmlTextView(gtk.TextView):
 
                 iterStart = iterEnd
 
-            self.clipboard.set_text(text)
-            self.clipboard.store()
+            clipboard = gtk.clipboard_get()
+            clipboard.set_text(text)
+            clipboard.store()
 
     def clear(self):
         self.get_buffer().set_text('')
