@@ -230,18 +230,18 @@ class MainClass( Plugin.Plugin ):
         ''' get avatar cover art '''
         path = self.player.getCoverPath()
         if path and os.path.exists(path):
-            print "Current song plugin : getCoverPath : [" + path + "]"
+            #print "Current song plugin : getCoverPath : [" + path + "]"
             return path
 
         path = self.search_local_image()  
         if path and os.path.exists(path):
-            print "Current song plugin : getCoverPath : [" + path + "]"
+            #print "Current song plugin : getCoverPath : [" + path + "]"
             return path
 
         if remote:
             try:
                 path = self.search_remote_image()
-                print "Current song plugin : getCoverPath : [" + path + "]"
+                #print "Current song plugin : getCoverPath : [" + path + "]"
                 return path
             except:
                 # handle connection errors
@@ -278,7 +278,7 @@ class MainClass( Plugin.Plugin ):
         if name == _('Autodetect'):
             for n in players:
                 if n.lower() != 'lastfm':
-                    print "Current song plugin: Trying " + n
+                    #print "Current song plugin: Trying " + n
                     if self._setPlayer(n, players) == 'loaded':
                         if not self.usingDummy and self.player.isRunning():
                             return
@@ -297,7 +297,7 @@ class MainClass( Plugin.Plugin ):
                 self.usingDummy = False
                 self.action()
             except Exception, e:
-                print "error initializing CurrentSong player:", e
+                #print "error initializing CurrentSong player:", e
                 error = e
             else:
                 self.player.log('info', _('Player: ') + name)
@@ -367,7 +367,7 @@ class MainClass( Plugin.Plugin ):
             "&itempage=1&newsearch=1&searchindex=Music"
 
         # This is useful to see if we're searching for the right song
-        print "Current song plugin: " + url
+        #print "Current song plugin: " + url
 
         albumart = urllib.urlopen(url).read()
         image_url = ""
