@@ -60,15 +60,16 @@ class MainClass(Plugin.Plugin):
         self.controller.emit('preferences-changed')  
         self.customStatus.unsetCustomStatus()
         self.customStatus.register_slash_commands()
-        statusMenuItem = gtk.MenuItem (_('Custom status...'), False)
-        statusMenuItem.connect("activate", self.on_status_menu_activated)
-        self.controller.mainWindow.userPanel.statusMenu.add(statusMenuItem)
+        self.statusMenuItem = gtk.MenuItem (_('Custom status...'), False)
+        self.statusMenuItem.connect("activate", self.on_status_menu_activated)
+        self.controller.mainWindow.userPanel.statusMenu.add(self.statusMenuItem)
         self.enabled = True
 
     def stop(self):
         self.disconnect(self.onStatusChangeId)
         self.controller.unifiedParser.disconnect(self.customStatusParserId)
         self.customStatus.unregister_slash_commands()
+        self.controller.mainWindow.userPanel.statusMenu.remove(self.statusMenuItem)
         self.enabled = False
 
     def check(self):
