@@ -295,6 +295,7 @@ try:
         @dbus.service.method(BUS_NAME)
         def get_last_display_picture(self, email='', cache=True):
             imagePath='noImage'
+            lista = []
             if cache:
                 try:
                     cachePath = self.controller.config.getCachePath()
@@ -389,3 +390,6 @@ try:
 
 except Exception, e:
     dbusError = e
+
+def debug(string):
+    print string
