@@ -15,6 +15,15 @@
 #    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 #Changelog:
+#0.5.1:
+#-Don't log "conversation started/closed" if just open an close conversation
+#-Fix a bug at stop of the plugin
+
+#0.5:
+#-Log all offline messages
+#-Fixed user menu for the new logs directories structure (dates)
+#-A lot of refactor
+
 #0.4.8:
 #-Fix Back consinstency for PyGtk in setting tooltips of a ToolItem
 
@@ -42,12 +51,12 @@
 
 VERSION = '0.4.8'
 import Plugin
-import dialog
 import os
 import time
 import emesenelib
 import desktop
 import gtk
+import gobject
 
 #From aaPluginDownloader
 try:
@@ -63,49 +72,31 @@ class MyLogger():
 
     def __init__(self,controller,conversation,MainClass,addButton = True):
         '''Save the identifier of this conversation and begin to log message'''
+        self.controller = controller
+        self.mainClass = MainClass
+        self.stopped = False
 
         #This identifier enable the check of members change!
         self.members = conversation.getMembers()
         self.idMyLog = self.members[0]
         for mem in self.members[1:len(self.members)]:
             self.idMyLog = self.idMyLog + '-' + mem
+        self.lastUserName = ''
 
         #The identifier of this conversation is the id of conversation
         self.idConv = id(conversation)
         self.conversation = conversation
 
-        self.mainClass = MainClass
-        #self.mainClass.activeLogger.append(self)
-        self.stopped = False
-
-        self.convId = conversation
-        self.controller = controller
-        #Every time the conversationManager send a close-conversation-ui
-        #execute stop
-        self.convmanagerId = self.controller.conversationManager.connect('close-conversation-ui', self.stop)
-
-        #We need to remember last username to show group conversation.
-        #Patched by Nelson (nelson at csie dot us)
-        self.lastUserName = ''
-
         #We would save logs in :
-        #paths.CONFIG_DIR join controller.config.getCurrentUser() join html_logs
-        self.logDir = os.path.join(CONFIG_PATH, \
-            controller.config.getCurrentUser()) #this dir exist!
-        maybeFaultDir = os.path.join(self.logDir, \
-            'html_logs') #This is created at the first run
+        self.logDir = os.path.join(self.mainClass.logsDir, \
+			time.strftime('%B_%Y', time.localtime(time.time()))) #This is created at the first run
 
         #If the log dir not exist create it
-        if os.path.exists(maybeFaultDir):
-            self.logDir = maybeFaultDir
-        else:
-            os.mkdir(maybeFaultDir)
-            # ugly, but "if os.mkdir(..)" doesn't work :S
-            if os.path.exists(maybeFaultDir):
-                self.logDir = maybeFaultDir
-                # if we can't create the dir, we put the file directly
-                # in logDir
-
+        if not os.path.exists(self.logDir):
+            try:
+                os.mkdir(self.logDir)
+            except: #in case we can't create the dir with the date
+                self.logDir = self.mainClass.logsDir 
 
         #Create the log FileName
         self.logFileName = os.path.join(self.logDir, \
@@ -125,6 +116,7 @@ class MyLogger():
             else:
                 #Last time we have not closed the file in the right way
                 #We put a br..
+                self.logFile.seek(0,2)
                 self.logFile.write('\n<span><br/></span>\n')
         else:
             self.logFile = open(self.logFileName,'w')
@@ -134,15 +126,7 @@ class MyLogger():
             convwith = _('Conversation with %s') % self.idMyLog
             self.logFile.write('<title>'+ convwith +'</title>\n</head>\n<body>\n')
 
-        #self.mainClass.debug('[LogConv] Logging in :' + self.logFileName)
-
-        #First string
-        started = _('Started at: ') 
-        self.logFile.write('<hr align=\"left\" />\n')
-        self.logFile.write('\n<span><span style=\"font-size: 10pt;font-weight: bold;\"> ' + started)
-        self.logFile.write(time.strftime('%a, %d %b %Y %H:%M:%S', time.localtime(time.time())))
-        self.logFile.write('.<br/></span></span>\n')
-        self.logFile.flush()
+        self.modified = False
 
         #For file send and receive logging
         self.p2p = controller.msn.p2p[conversation.switchboard.firstUser]
@@ -151,41 +135,49 @@ class MyLogger():
         self.sendmessageId = self.controller.conversationManager.connect( \
                                     'send-message', self.logSendMessage)
         self.receivemessageId = self.controller.conversationManager.connect( \
-                                    'receive-message', self.logReceivedMessage)
-        self.receiveOffmessageId = self.mainClass.connect( \
-                                    'offline-message-received', self.logOffReceivedMessage)
-        self.fileTransferId = self.p2p.connect('file-transfer-accepted',self.logFileTransfer)
+                             'receive-message', self.logReceivedMessage)
+        self.fileTransferId = self.p2p.connect('file-transfer-accepted',\
+                                                   self.logFileTransfer)
+        #Every time the conversationManager send a close-conversation-ui
+        #execute stop
+        self.closeUIId = self.controller.conversationManager.connect(\
+                                     'close-conversation-ui', self.stop)
 
         if addButton:
             #Add a button to the toolbar of this conversation:
-            self.logButton = gtk.ToolButton()
-            self.logButton.set_label(_('Logs'))
+            self.logButton = gtk.ToolButton(label=_('Logs'))
             self.logButton.set_stock_id(gtk.STOCK_DND)
             if self.controller.theme.getImage('log'):
                 imagelog = gtk.Image()
                 imagelog.set_from_pixbuf(self.controller.theme.getImage('log'))
                 imagelog.show()
                 self.logButton.set_icon_widget(imagelog)
-            self.logButton.connect('clicked',self.viewLog)
+            self.logButton.connect('clicked', self.mainClass.viewLog, self.logFileName)
 
             self.logButton.set_tooltip_text(_('View the logs of this conversation'))
 
             conversation.ui.input.toolbar.insert(gtk.SeparatorToolItem(), -1)
             conversation.ui.input.toolbar.insert(self.logButton, -1)
-
             conversation.ui.input.toolbar.show_all()
-
-
-    def viewLog(self, *args):
-        desktop.open(self.logFileName)
+            
+    def start_conv_log(self):
+        #First string
+        started = _('Started at: ') 
+        self.logFile.write('<hr align=\"left\" />\n')
+        self.logFile.write('\n<span><span style=\"font-size: 10pt;font-weight: bold;\"> ' + started)
+        self.logFile.write(time.strftime('%a, %d %b %Y %H:%M:%S', time.localtime(time.time())))
+        self.logFile.write('.<br/></span></span>\n')
+        self.logFile.flush()
+        self.modified = True
 
     def logSendMessage(self, obj, conversation, message):
         '''message is a list of string'''
-
         idThisLog = id(conversation)
 
         #Log this message if the id match
         if idThisLog == self.idConv:
+            if not self.modified:
+                self.start_conv_log()
             #Members have changed??
             members = conversation.getMembers()
             mbThisLog = members[0]
@@ -195,15 +187,17 @@ class MyLogger():
             if mbThisLog != self.idMyLog:
                 self.stop()
                 self.__init__(self.controller,self.conversation,self.mainClass,False)
+                self.mainClass.activeLoggers.append(self)
 
             self.appendOutputText(conversation.getUser(), message, 'outgoing')
 
     def logReceivedMessage(self, cm, conversation, mail, nick, message, format, charset, p4c):
-
         idThisLog = id(conversation)
 
         #Log this message if the id match
         if idThisLog == self.idConv:
+            if not self.modified:
+                self.start_conv_log()
             #Members have changed??
             members = conversation.getMembers()
             mbThisLog = members[0]
@@ -213,23 +207,11 @@ class MyLogger():
             if mbThisLog != self.idMyLog:
                 self.stop()
                 self.__init__(self.controller,self.conversation,self.mainClass,False)
+                self.mainClass.activeLoggers.append(self)
 
             self.appendOutputText(mail, message, 'incoming', \
                 conversation.parseFormat(mail, format))
 
-    def logOffReceivedMessage(self, msnp, oim):
-        '''called when someone sent an offline message'''
-
-        user, date, message = oim
-        mail = user['addr']
-
-        result = self.controller.conversationManager.getOpenConversation(mail)
-        if result != None:
-            idThisLog = id(result[1]) #conversation
-            if idThisLog == self.idConv:
-                self.appendOutputText(mail, message, 'offline_incoming', \
-                                time.mktime(date))
-
     def logFileTransfer(self, p2p, session, context, sender):
 
         mail = sender
@@ -238,6 +220,8 @@ class MyLogger():
         self.members = self.conversation.getMembers()
         for mem in self.members:
             if (mail == mem) or (mail == 'Me'):
+                if not self.modified:
+                    self.start_conv_log()
                 self.appendOutputText(None, \
                         _('Starting transfer of %s') % context.filename, \
                         'information')
@@ -246,14 +230,15 @@ class MyLogger():
     #From in Conversation.py with another end
     def appendOutputText(self, username, text, type, style = None, timestamp = None):
         '''append the given text to the outputFile type is in[incoming:outgoing]'''
-
+        if not self.modified:
+            self.start_conv_log()
         if type.startswith('ink_'):
             type = type[4:]
             ink = True
         else:
             ink = False
 
-        if username == self.convId.switchboard.user:
+        if username == self.conversation.switchboard.user:
             nick = emesenelib.common.escape(self.controller.msn.nick)
         elif username != None:
             nick = emesenelib.common.escape( \
@@ -265,23 +250,23 @@ class MyLogger():
             timestamp = time.time()
 
         if self.lastUserName == username:
+            if type != "offline_incoming":
+                type = "consecutive_"+type
             displayedText = self.controller.conversationLayoutManager.layout(\
-                username, text, style, self.convId, 'consecutive_' + type, timestamp, ink)
+                username, text, style, self.conversation, type, timestamp, ink)
         else:
             self.lastUserName = username
             displayedText = self.controller.conversationLayoutManager.layout(\
-                username, text, style, self.convId, type, timestamp, ink)
+                username, text, style, self.conversation, type, timestamp, ink)
 
         #erase custom emoticons
         displayedText = self.fromCustomEmoticonsToText(displayedText)
-
         self.logFile.write('<!---->' + displayedText)
         self.logFile.write('\n')
         self.logFile.flush()
 
     def stop(self, conversationManager = None, conversation = None, window = None):
         '''Close this logger if the id of the conversation closed match with self.idMyLog'''
-
         if self.stopped:
             return
 
@@ -293,21 +278,22 @@ class MyLogger():
         #Close this logger if the id match
         if idThisLog == self.idConv:
             #Last String
-            closed = _('Closed at: ')
-            self.logFile.write('\n<span><span style=\"font-size: 10pt;font-weight: bold;\">'+ closed)
-            self.logFile.write(time.strftime('%a, %d %b %Y %H:%M:%S',time.localtime(time.time())))
-            self.logFile.write('.<br/></span></span>\n')
-            #Tail of the document
-            self.logFile.write('\n</body></html>\n')
+            if self.modified:
+                closed = _('Closed at: ')
+                self.logFile.write('\n<span><span style=\"font-size: 10pt;font-weight: bold;\">'+ closed)
+                self.logFile.write(time.strftime('%a, %d %b %Y %H:%M:%S',time.localtime(time.time())))
+                self.logFile.write('.<br/></span></span>\n')
+                #Tail of the document
+                self.logFile.write('\n</body></html>\n')
 
             self.logFile.close()
 
             self.controller.conversationManager.disconnect(self.sendmessageId)
             self.controller.conversationManager.disconnect(self.receivemessageId)
-            self.controller.conversationManager.disconnect(self.convmanagerId)
-            self.mainClass.disconnect(self.receiveOffmessageId)
+            self.controller.conversationManager.disconnect(self.closeUIId)
             self.p2p.disconnect(self.fileTransferId)
             self.stopped = True
+            self.mainClass.activeLoggers.remove(self)
 
     def fromCustomEmoticonsToText(self,message):
 
@@ -365,91 +351,106 @@ class MyLogger():
 class MainClass(Plugin.Plugin):
     '''Main plugin class'''
 
-    description = _('Log every session with friendEmail in:\n' +\
-                    '~/.config/emesene1.0/<address>/html_logs/friendEmail.html')
-    authors = { 'Marramao' : 'maramaopercheseimorto@gmail.com'}
+    description = _('Log every session with friendEmail in:\n' + \
+      '~/.config/emesene1.0/<address>/html_logs/month_year/friendEmail.html')
+    authors = { 'Marramao' : 'maramaopercheseimorto@gmail.com', \
+                'arielj' : 'arieljuod@gmail.com' }
     website = 'emesene.org'
     displayName = _('Conversation Logger')
     name = 'LogConversation'
 
-    activeLogger = []
-
     def __init__(self, controller, msn):
         '''Contructor'''
         Plugin.Plugin.__init__(self, controller, msn)
 
-        self.description = _('Log every session with friendEmail in:\n' +\
-                    '~/.config/emesene1.0/<address>/html_logs/friendEmail.html')
-        self.authors = { 'Marramao' : 'maramaopercheseimorto@gmail.com'}
-        self.website = 'emesene.org'
-        self.displayName = _('Conversation Logger')
-        self.name = 'LogConversation'
-
         self.controller = controller
         self.config = controller.config
         self.config.readPluginConfig(self.name)
-        self.enabled = False
 
-        self.convmanagerId = 0
-        #self.debug( '[LogConv] Initialized.\n')
-
-        #self.start()
+        self.activeLoggers = []
 
     def start(self):
         '''start the plugin'''
-        if self.enabled ==False:
-            self.convmanagerId = self.controller.conversationManager.connect( \
+        self.convmanagerId = self.controller.conversationManager.connect( \
                 'new-conversation-ui', self.connectLogger)
-            self.menuItemId = self.controller.connect("usermenu-item-add", self.add_usermenu_item)
+        self.menuItemId = self.controller.connect("usermenu-item-add", \
+                                                  self.add_usermenu_item)
+        self.offlineMessages = self.connect('offline-message-received', \
+                                              self.logOffReceivedMessage)
+
+        self.logsDir = os.path.join(CONFIG_PATH, \
+                 self.controller.config.getCurrentUser(), 'html_logs')
+
+        if not os.path.isdir(self.logsDir):
+            os.mkdir(self.logsDir)
 
         self.enabled = True
 
-        #self.debug( '[LogConv] Started.\n')
-
     def connectLogger (self, conversationManager, conversation, window):
-        self.newLogger = MyLogger(self.controller,conversation,self)
-    
-    def add_usermenu_item(self, controller, userMenu):
-        logDir = os.path.join(CONFIG_PATH, \
-            controller.config.getCurrentUser())
-        maybeFaultDir = os.path.join(logDir, \
-            'html_logs')
-        if os.path.exists(maybeFaultDir):
-            logDir = maybeFaultDir
-        else:
-            os.mkdir(maybeFaultDir)
-            if os.path.exists(maybeFaultDir):
-                self.logDir = maybeFaultDir
-        self.logFileName = os.path.join(logDir, \
-            userMenu.user.email + '.html')
-            
-        if os.path.exists(self.logFileName):
-            self.logMenuItem = userMenu.newImageMenuItem( _( "Logs of this conversation" ),
-                gtk.STOCK_DND )
-            if self.controller.theme.getImage('log'):
-                imagelog = gtk.Image()
-                imagelog.set_from_pixbuf(self.controller.theme.getImage('log'))
-                imagelog.show()
-                self.logMenuItem.set_icon_widget(imagelog)
-            userMenu.viewMenu.add( self.logMenuItem )
-            self.logMenuItem.show()
-            self.logMenuItem.connect( 'activate', self.viewLog )
+        self.activeLoggers.append(MyLogger(self.controller,conversation,self))
 
-    def viewLog(self, *args):
-        desktop.open(self.logFileName)
+    def logOffReceivedMessage(self, msnp, oim):
+        '''used when a new conversation is opened by an offline message'''
+        def check(oim):
+            user, date, message = oim
+            mail = user['addr']
+            result = self.controller.conversationManager.getOpenConversation(mail)
+            
+            if result is not None:
+                conversation = result[1]
+                for logger in self.activeLoggers:
+                    if logger.conversation == conversation:
+
+                        try:
+                            logger.appendOutputText(mail, message, 'offline_incoming', \
+                                time.mktime(date))
+                            return False
+                        except:
+                            pass
+                return True
+            return True
+
+        gobject.timeout_add(500, check, oim)
+
+    def add_usermenu_item(self, controller, userMenu):
+        dates = os.listdir(self.logsDir)
+        logMenuItem = userMenu.newImageMenuItem( _( "Logs of this user" ),
+                                                           gtk.STOCK_DND )
+        if self.controller.theme.getImage('log'):
+            imagelog = gtk.Image()
+            imagelog.set_from_pixbuf(self.controller.theme.getImage('log'))
+            imagelog.show()
+            logMenuItem.set_icon_widget(imagelog)
+
+        submenu = gtk.Menu()
+        logsAvailables = False
+        for date in dates:
+            logFileName = os.path.join(self.logsDir, date, \
+                                       userMenu.user.email + '.html')
+            if os.path.exists(logFileName):
+                newMenuItem = gtk.MenuItem(label=date)
+                newMenuItem.connect( 'activate', self.viewLog, logFileName )
+                submenu.append(newMenuItem)
+                logsAvailables = True
+
+        if logsAvailables:
+            logMenuItem.set_submenu(submenu)
+            userMenu.viewMenu.add(logMenuItem)
+            logMenuItem.show_all()
+
+    def viewLog(self, menuitem, logFileName):
+        desktop.open(logFileName)
 
     def stop(self):
         '''stop the plugin'''
         self.controller.conversationManager.disconnect(self.convmanagerId)
-        #print '[LogConv]I\'m going to close %d active loggers.' % len(self.activeLogger)
         self.controller.disconnect(self.menuItemId)
+        self.disconnect(self.offlineMessages)
 
-        if len(self.activeLogger) > 0:
-            for myLogger in self.activeLogger:
-                myLogger.stop()
+        for myLogger in self.activeLoggers:
+            myLogger.stop()
         
         self.enabled = False
-        #self.debug( '[LogConv] Stopped.\n')
 
     def check(self):
         return (True, 'Ok')
