@@ -290,14 +290,24 @@ class Logger(object):
 
     def get_conversation_ids(self, account):
         '''return the ids of the conversations where the contact was present'''
+        #in the inner query i select all convs ids where the contact is present
+        #in the outer query i select only convs where there is at 
+        #least one message! --cando
 
-        query = '''select distinct c.id, c.started
+        query = '''select co.id,co.started
+        from conversation co,conversation_event coe,event ev
+        where co.id = coe.id_conversation 
+        and coe.id_event = ev.id and ev.name = 'message'
+        and co.id in ( select distinct c.id
         from conversation c, event e, conversation_event ce, user u
         where c.id = ce.id_conversation and
         e.id = ce.id_event and
         ce.id_user = u.id and
-        u.account = "%s"
-        order by c.started'''
+        u.account = "%s")
+        group by co.id
+        having count(*) >= 1
+        order by co.started
+        '''
 
         return self.query(query % (account,))
 
@@ -340,7 +350,7 @@ class Logger(object):
 class MainClass(Plugin.Plugin):
     '''Main plugin class'''
 
-    description = _('Log all events to a file')
+    description = _('Log all events and conversations in a database')
     authors = {'Mariano Guerra' :
         'luismarianoguerra at gmail dot com'}
     website = 'http://emesene.org'
@@ -350,7 +360,7 @@ class MainClass(Plugin.Plugin):
         '''Contructor'''
         Plugin.Plugin.__init__(self, controller, msn, 1000)
 
-        self.description = _('Log all events to a file')
+        self.description = _('Log all events and conversations in a database')
         self.authors = {'Mariano Guerra' :
             'luismarianoguerra at gmail dot com'}
         self.website = 'http://emesene.org'
@@ -398,7 +408,29 @@ class MainClass(Plugin.Plugin):
             self._cb_sb_action_message_sent
         self.signals['switchboard::custom-emoticon-received'] = \
             self._cb_sb_custom_emoticon_received
+        self.signals['switchboard::user-join'] = self._cb_sb_user_join
 
+        self.signals_labels = {}
+        self.signals_labels['self-nick-changed'] = _('Self nick changed')
+        self.signals_labels['personal-message-changed'] = _('PM changed')
+        self.signals_labels['self-status-changed'] = _('Self status changed')
+        self.signals_labels['self-personal-message-changed'] = _('Self PM changed')
+        self.signals_labels['self-current-media-changed'] = _('Self current media changed')
+        self.signals_labels['nick-changed'] = _('Nick changed')
+        self.signals_labels['contact-status-change'] = _('Contact status changed')
+        self.signals_labels['initial-status-change'] = _('Initial status changed')
+        self.signals_labels['user-offline'] = _('User offline')
+        self.signals_labels['display-picture-changed'] = _('Display picture changed')
+        self.signals_labels['switchboard::message'] = _('Message received')
+        self.signals_labels['switchboard::ink-message'] = _('Ink message received')
+        self.signals_labels['switchboard::nudge'] = _('Nudge received')
+        self.signals_labels['switchboard::message-sent'] = _('Message sent')
+        self.signals_labels['switchboard::ink-sent'] = _('Ink message sent')
+        self.signals_labels['switchboard::nudge-sent'] = _('Nudge sent')
+        self.signals_labels['switchboard::action-message'] = _('Action message received')
+        self.signals_labels['switchboard::action-sent'] = _('Action message sent')
+        self.signals_labels['switchboard::custom-emoticon-received'] = _('Custom emoticon received')
+        self.signals_labels['switchboard::user-join'] = _('User joined conversation')
         # functions to be called on mainloop idleness
         self.queued = []
         self.queuedtag = 0
@@ -662,6 +694,7 @@ class MainClass(Plugin.Plugin):
 
         textview = gtk.TextView()
         self.textBuffer = textview.get_buffer()
+        self.textBuffer.create_tag('highlight', background = 'yellow')
 
         scroll = gtk.ScrolledWindow()
         scroll.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
@@ -673,7 +706,7 @@ class MainClass(Plugin.Plugin):
         self.textview.set_editable(False)
         self.textview.set_cursor_visible(False)
 
-        scroll.add_with_viewport(self.textview)
+        scroll.add(self.textview)
 
         hbox = gtk.HBox(False, 5)
         saveButton = gtk.Button(stock=gtk.STOCK_SAVE)
@@ -684,10 +717,49 @@ class MainClass(Plugin.Plugin):
 
         closeButton = gtk.Button(stock=gtk.STOCK_CLOSE)
         closeButton.connect("clicked", lambda w: self.window.hide())
+        
+        ############ Search TreeView ###################
+        self.search_active = False
+        
+        self.searchStore = gtk.ListStore(str, str, str, str)
+        self.searchTree = gtk.TreeView(self.searchStore)
+        self.searchTree.connect("row-activated", self.set_cursor)
+        self.searchTree.set_rules_hint(True)
+        cell = gtk.CellRendererText()
+        
+        nameCol = gtk.TreeViewColumn(_("Date"), cell, text=0)
+        dateCol = gtk.TreeViewColumn(_("Time"), cell, text=1)
+        timeCol = gtk.TreeViewColumn(_("Name"), cell, text=2)
+        msgCol = gtk.TreeViewColumn(_("Message"), cell, text=3)
+        
+        nameCol.set_resizable(True)
+        dateCol.set_resizable(True)
+        timeCol.set_resizable(True)        
+        msgCol.set_resizable(True)
+        
+        self.searchTree.append_column(nameCol)
+        self.searchTree.append_column(dateCol)
+        self.searchTree.append_column(timeCol)
+        self.searchTree.append_column(msgCol)
+        
+        self.searchSw = gtk.ScrolledWindow()
+        self.searchSw.set_policy(gtk.POLICY_AUTOMATIC, gtk.POLICY_AUTOMATIC)
+        self.searchSw.add(self.searchTree)
+        self.searchSw.set_size_request(100, 30)
+        
+        ##################################################
+        
+        #search box
+        searchLabel = gtk.Label(_("Search:"))
+        self.searchBox = gtk.Entry()
+        self.searchBox.connect("key-press-event", self.enter_pressed)
+        
 
         hbox.pack_end(saveButton, False, False)
         hbox.pack_end(refreshButton, False, False)
         hbox.pack_end(closeButton, False, False)
+        hbox.pack_end(self.searchBox, False, False)
+        hbox.pack_end(searchLabel, False, False)
 
         textRenderer = gtk.CellRendererText()
         column = gtk.TreeViewColumn(_("Date"), textRenderer, markup=0)
@@ -711,6 +783,7 @@ class MainClass(Plugin.Plugin):
         vbox = gtk.VBox(spacing=5)
         vbox.pack_start(hPaned)
         vbox.pack_start(hbox, False, False)
+        vbox.pack_start(self.searchSw)
         vbox.pack_start(gtk.Statusbar(), False, False)
 
         self.datesStamps = {}
@@ -720,6 +793,65 @@ class MainClass(Plugin.Plugin):
         else:
             self.window.add(vbox)
             self.window.show_all()
+        
+        self.searchSw.hide_all()   
+            
+    def set_cursor(self, treeview, path, col):
+        (model, iter) = self.searchTree.get_selection().get_selected()
+        dateSearch = self.searchStore.get_value(iter, 0)
+        timeSearch = self.searchStore.get_value(iter, 1)
+        
+        #Search in the datesTree
+        self.datesTree.set_cursor_on_cell(0)
+        (model, iter) = self.datesTree.get_selection().get_selected()
+        while iter:
+            date = self.datesListstore.get_value(iter, 0)
+            
+            if date == dateSearch:
+                self.datesTree.set_cursor_on_cell(model.get_path(iter))
+                break
+            
+            iter = model.iter_next(iter)
+            
+        self.scroll_to_result(timeSearch)
+            
+    def scroll_to_result(self, timee):
+        start_iter = self.textBuffer.get_start_iter()
+        result = start_iter.forward_search(timee, gtk.TEXT_SEARCH_VISIBLE_ONLY,
+                None)
+                
+        if result is not None:
+            match_start_iter, match_end_iter = result
+            match_start_iter.backward_char() #include '(' or other character before time
+            match_end_iter.forward_line() #highlight all message not just time
+            
+            self.textBuffer.apply_tag_by_name('highlight', match_start_iter,
+                    match_end_iter)
+                    
+            match_start_mark = self.textBuffer.create_mark('match_start',
+                    match_start_iter, True)
+                    
+            self.textview.scroll_to_mark(match_start_mark, 0, True)
+
+    def enter_pressed(self, button, event):
+        if len(self.searchBox.get_text()) == 0:
+            self.searchSw.hide_all()
+        elif event.keyval == 65293 or event.keyval == 65421: #If enter key is pressed
+            self.searchStore.clear()
+            text = self.searchBox.get_text()
+            self.searchSw.show_all()
+            self.datesTree.set_cursor_on_cell(0)
+            (model, iter) = self.datesTree.get_selection().get_selected()
+            self.search_active = True
+            while iter:
+                self.searchIter = iter
+                self.searchText = text
+                self.datesTree.set_cursor_on_cell(model.get_path(iter))
+                iter = model.iter_next(iter)
+                
+            self.search_active = False
+                
+            self.textview.get_buffer().set_text("")
 
     def fill_dates_tree(self, mail):
         '''fill the treeview with the logs dates'''
@@ -752,41 +884,56 @@ class MainClass(Plugin.Plugin):
                 self.datesTree.get_selection().get_selected()[1], 0)[0]
         except (TypeError, AttributeError):
             return
-
+        
+        string1 = (_('Conversation opened'))
+        string2 = (_('Conversation closed'))
         ids_conversation = self.datesStamps[selected]
         nick_cache = {}
         self.textview.get_buffer().set_text("")
-        for id_conversation in ids_conversation:
-            for (stamp, mail, message) in \
-                 self.logger.get_conversation(id_conversation, 10000):
+        for id_conversation in ids_conversation:         
+            listMessages = self.logger.get_conversation(id_conversation, 10000)
+            if (len(listMessages)!= 0):
+                self.textview.display_html('<body><span style=\"font-weight: bold;\"><b>*** '+string1+' ***</b>'
+                                            '</span></body>')
+                for (stamp, mail, message) in listMessages:
 
-                if mail in nick_cache:
-                    if nick_cache[mail]['next'] is not None and \
-                        nick_cache[mail]['next'] <= stamp:
+                    if mail in nick_cache:
+                        if nick_cache[mail]['next'] is not None and \
+                            nick_cache[mail]['next'] <= stamp:
+                            nick = self.logger.get_user_nick(mail, stamp)
+                            next = self.logger.get_next_nick_stamp(mail, stamp)
+                            nick_cache[mail] = {'nick': nick, 'next' : next}
+                        else:
+                            nick = nick_cache[mail]['nick']
+                    else:
                         nick = self.logger.get_user_nick(mail, stamp)
                         next = self.logger.get_next_nick_stamp(mail, stamp)
                         nick_cache[mail] = {'nick': nick, 'next' : next}
-                    else:
-                        nick = nick_cache[mail]['nick']
-                else:
-                    nick = self.logger.get_user_nick(mail, stamp)
-                    next = self.logger.get_next_nick_stamp(mail, stamp)
-                    nick_cache[mail] = {'nick': nick, 'next' : next}
 
-                date = time.ctime(float(stamp)).split()[3]
-                (_format, encoding, text) = message.split('\r\n', 2)
-                style = parse_format(_format)
-                nick = self.controller.unifiedParser.getParser(nick).get()
-                text = self.controller.unifiedParser.getParser(text).get()
-                text = text.replace("\r\n", "\n").replace("\n", "<br />")
+                    date = time.ctime(float(stamp)).split()[3]
+                    (_format, encoding, text) = message.split('\r\n', 2)
+                    style = parse_format(_format)
+                    nick = self.controller.unifiedParser.getParser(nick).get()
+                    text = self.controller.unifiedParser.getParser(text).get()
+                    text = text.replace("\r\n", "\n").replace("\n", "<br />")
+                    
+                    if self.search_active:    
+                        date2 = self.datesListstore.get_value(self.searchIter, 0)
+                        if text.find(self.searchText) != -1:
+                            self.searchStore.append([date2, date, nick, text])
 
-                try:
-                    self.textview.display_html('<body>(%s) <b>%s: </b>'
-                        '<span style="%s">%s</span></body>' % (date, nick, style, text))
-                except:
-                    # hide messages that we can't display
-                    pass
-            self.textview.display_html('<br/>')
+                    try:
+                        self.textview.display_html('<body>(%s) <b>%s: </b>'
+                            '<span style="%s">%s</span></body>' % (date, nick, style, text))
+                    except:
+                        # hide messages that we can't display
+                        pass
+                self.textview.display_html('<body><span style=\"font-weight: bold;\"><b>*** '+string2+' ***</b>'
+                                            '</span></body>')
+                self.textview.display_html('<br/>')
+
+            else:
+                pass
 
 
     def on_save_logs(self, button):
@@ -982,12 +1129,13 @@ class MainClass(Plugin.Plugin):
 
     def configure( self ):
         configuration = []
-        configuration.append(Plugin.Option('', gtk.Widget, '', '', gtk.Label("Enable/disable events")))
+        configuration.append(Plugin.Option('', gtk.Widget, '', '', gtk.Label(_("Enable/disable events to be logged:"))))
         for signal in self.signals:
-            configuration.append(Plugin.Option(signal, bool, signal.replace('-',' '), \
+            configuration.append(Plugin.Option(signal, bool, self.signals_labels[signal], \
             '', bool(int(self.config.getPluginValue(self.name, signal, True)))))
 
         configWindow = Plugin.ConfigWindow( 'Logger', configuration )
+        configWindow.vbox.set_spacing(0)
         response = configWindow.run()
         if response != None:
             for signal in self.signals:
