@@ -20,6 +20,7 @@ import gtk
 import time
 import gobject
 import pango
+import os
 
 import Plugin
 import dialog
@@ -32,6 +33,44 @@ from Theme import resizePixbuf
 
 growFactor = 20 # the number of pixels to grow every iteration
 
+# This code is used only on Windows to get the location on the taskbar
+taskbarOffsety = 0
+taskbarOffsetx = 0
+if os.name == "nt":
+    import ctypes
+    from ctypes.wintypes import RECT, DWORD
+    user = ctypes.windll.user32
+    MONITORINFOF_PRIMARY = 1
+    HMONITOR = 1
+
+    class MONITORINFO(ctypes.Structure):
+        _fields_ = [
+            ('cbSize', DWORD),
+            ('rcMonitor', RECT),
+            ('rcWork', RECT),
+            ('dwFlags', DWORD)
+            ]
+
+    taskbarSide = "bottom"
+    taskbarOffset = 30
+    info = MONITORINFO()
+    info.cbSize = ctypes.sizeof(info)
+    info.dwFlags =  MONITORINFOF_PRIMARY
+    user.GetMonitorInfoW(HMONITOR, ctypes.byref(info))
+    if info.rcMonitor.bottom != info.rcWork.bottom:
+        taskbarOffsety = info.rcMonitor.bottom - info.rcWork.bottom
+    if info.rcMonitor.top != info.rcWork.top:
+        taskbarSide = "top"
+        taskbarOffsety = info.rcWork.top - info.rcMonitor.top
+    if info.rcMonitor.left != info.rcWork.left:
+        taskbarSide = "left"
+        taskbarOffsetx = info.rcWork.left - info.rcMonitor.left
+    if info.rcMonitor.right != info.rcWork.right:
+        taskbarSide = "right"
+        taskbarOffsetx = info.rcMonitor.right - info.rcWork.right
+
+
+
 class PixmapDialog(gtk.Dialog):
     '''a dialog to set Notification Pixmap'''
     def __init__(self, filename, font, color, online, offline, \
@@ -293,7 +332,7 @@ class Notification(gtk.Window):
                 callback = None, params = None, userPixbuf = None, \
                 font = None, color = None):
 
-        gtk.Window.__init__(self, type=gtk.gdk.WINDOW_TOPLEVEL)
+        gtk.Window.__init__(self, type=gtk.WINDOW_POPUP)
 
         if corner == 0:
             self.set_gravity(gtk.gdk.GRAVITY_NORTH_WEST)
@@ -304,9 +343,9 @@ class Notification(gtk.Window):
         else:
             self.set_gravity(gtk.gdk.GRAVITY_SOUTH_EAST)
 
-        self.set_accept_focus(False)
-        self.set_decorated(False)
-        self.set_type_hint(gtk.gdk.WINDOW_TYPE_HINT_SPLASHSCREEN)
+        #self.set_accept_focus(False)
+        #self.set_decorated(False)
+        #self.set_type_hint(gtk.gdk.WINDOW_TYPE_HINT_UTILITY)
 
         self.corner = corner
         self.scroll = scroll
@@ -395,26 +434,32 @@ class Notification(gtk.Window):
     def _resize(self):
         ''' change the size and position '''
 
-        if self.scroll == 0: 
+        if self.offset == 0:
+            sumx = taskbarOffsetx
+            sumy = taskbarOffsety
+        else:
+            sumx = 0
+            sumy = 0
+        if self.scroll == 0:
             if self.corner == 0 or self.corner == 2:
-                l = self.offset
+                l = self.offset + sumx
             else:
-                l = gtk.gdk.screen_width() - self.offset - self.width
+                l = gtk.gdk.screen_width() - self.offset - self.width - sumx
 
             if self.corner == 0 or self.corner == 1:
-                t = 0
+                t = 0 + taskbarOffsety
             else:
-                t = gtk.gdk.screen_height() - self.height
+                t = gtk.gdk.screen_height() - self.height - taskbarOffsety
         else:
             if self.corner == 0 or self.corner == 2:
-                l = 0
+                l = 0 + taskbarOffsetx
             else:
-                l = gtk.gdk.screen_width() - self.width
+                l = gtk.gdk.screen_width() - self.width - taskbarOffsetx
 
             if self.corner == 0 or self.corner == 1:
-                t = self.offset
+                t = self.offset + sumy
             else:
-                t = gtk.gdk.screen_height() - self.offset - self.height
+                t = gtk.gdk.screen_height() - self.offset - self.height - sumy
 
         self.move(l, t)
         self.resize(self.width, self.height)
@@ -432,7 +477,7 @@ class Notification(gtk.Window):
 
         if animate and offset < self.offset:
             self.offset -= growFactor
-            if offset > offset:
+            if offset < self.offset:
                 self.offset = offset
         else:
             self.offset = offset
@@ -676,8 +721,17 @@ class MainClass(Plugin.Plugin):
         self.controller.newConversation(None, params[0], params[1], True)
 
     def openMail(self, params):
-        desktop.open(self.controller.hotmail.getLoginPage\
-                (params[0], params[1], params[2]))
+        if self.config.glob['overrideMail'] == '':
+            try:
+                desktop.open(self.controller.hotmail.getLoginPage\
+                    (params[0], params[1], params[2]))
+            except OSError:
+                dialog.error(_('Couldn\'t launch the default browser'))
+        else:
+            try:
+                subprocess.Popen(self.config.glob['overrideMail'])
+            except:
+                dialog.error(_('Couldn\'t launch the e-mail client'))
 
     def connect_onoff(self, *args):
         self.onlineId = self.connect('user-online', self.online)
