@@ -205,13 +205,13 @@ class PlusButton(gtk.ToolButton):
 
 class MainClass(Plugin.Plugin):
     
-    description = _('A panel for applying Messenger Plus formats to the text') 
+    description = _('Panel for applying color tags to the text') 
     authors = { 'mg' : 'themgzzy at gmail dot com' }
     displayName = _('Plus Color Panel')
     name = 'PlusColorPanel'
     def __init__(self, controller, msn):
         Plugin.Plugin.__init__(self, controller, msn)
-        self.description = _('A panel for applying Messenger Plus formats to the text') 
+        self.description = _('Panel for applying color tags to the text') 
         self.authors = { 'mg' : 'themgzzy at gmail dot com' }
         self.displayName = _('Plus Color Panel')
         self.name = 'PlusColorPanel'
