@@ -20,36 +20,22 @@ import os
 import gtk
 import gobject
 import tempfile
-import threading
-import time
 
 import Plugin
 
-description = _('Take screenshots and send them with /screenshot [save] [<seconds>]')
-authors = { 'Dx' : 'dx@dxzone.com.ar' }
-website = 'http://www.dxzone.com.ar'
-displayName = _('Screenshots')
-name = 'Screenshots'
-
 class MainClass(Plugin.Plugin):
     '''Main plugin class'''
-
-    description = _('Take screenshots and send them with \
-            /screenshot [save] [<seconds>]')
-    authors = { 'Dx' : 'dx@dxzone.com.ar' }
+    description = _('Take screenshots and send them with /screenshot [save] [<seconds>]')
+    authors = { 'Dx' : 'dx@dxzone.com.ar',
+                'arielj' : 'arieljuod@gmail.com'}
     website = 'http://www.dxzone.com.ar'
     displayName = _('Screenshots')
     name = 'Screenshots'
+
     def __init__( self, controller, msn ):
         '''Constructor'''
 
         Plugin.Plugin.__init__( self, controller, msn )
-        self.description = _('Take screenshots and send them with \
-                /screenshot [save] [<seconds>]')
-        self.authors = { 'Dx' : 'dx@dxzone.com.ar' }
-        self.website = 'http://www.dxzone.com.ar'
-        self.displayName = _('Screenshots')
-        self.name = 'Screenshots'
         
         self.config = controller.config
         self.config.readPluginConfig(self.name)
@@ -58,10 +44,7 @@ class MainClass(Plugin.Plugin):
         self.slash = controller.Slash
         self.msn = msn
         
-        if os.name == 'posix':
-            self.root = controller.mainWindow.get_root_window()
-        else:
-            self.root = None
+        self.root = gtk.gdk.get_default_root_window()
 
     def start( self ):
         '''start the plugin'''
@@ -96,30 +79,16 @@ class MainClass(Plugin.Plugin):
             self.do(slashAction, save)
 
     def do(self, slashAction, save):
-        if os.name == 'nt':
-            print 'screenshot on windows never tested, check source!'
+        temp = tempfile.mkstemp(prefix='screenshot', suffix='.png')
+        os.close(temp[0])
 
-            # yes, i had to break this link.. 80 cols :P
-            ## mail.python.org/pipermail/python-win32/
-            ## .../2003-January/000709.html
-
-            # import win32api, win32clipboard
-            # win32api.keybd_event(win32con.VK_PRINT, 0)
-            # win32clipboard.OpenClipboard(0)
-            # data = win32clipboard.GetClipboardData(win32clipboard.CF_DIB)
-            # win32clipboard.CloseClipboard()
-        elif os.name == 'posix':
-            temp = tempfile.mkstemp(prefix='screenshot', suffix='.png')
-            os.close(temp[0])
-            
-            # überfast screenshots! 1.9secs in my pentium II 350mhz
-            # er.. yes, that's fast.. try running import
-            size = self.root.get_size()
-            colormap = self.root.get_colormap()
-            pixmap = gtk.gdk.pixmap_foreign_new(self.root.xid)
-            pixbuf = gtk.gdk.Pixbuf(gtk.gdk.COLORSPACE_RGB, 0, 8, *size)
-            pixbuf.get_from_drawable(pixmap, colormap, 0, 0, 0, 0, *size)
-            pixbuf.save(temp[1], 'png')
+        # überfast screenshots! 1.9secs in my pentium II 350mhz
+        # er.. yes, that's fast.. try running import
+        size = self.root.get_size()
+        colormap = self.root.get_colormap()
+        pixbuf = gtk.gdk.Pixbuf(gtk.gdk.COLORSPACE_RGB, 0, 8, *size)
+        pixbuf.get_from_drawable(self.root, colormap, 0, 0, 0, 0, *size)
+        pixbuf.save(temp[1], 'png')
             
         if not save:
             slashAction.conversation.sendFile(temp[1])
