@@ -41,7 +41,7 @@ class CurrentSong(object):
         self.status = _('unknown')
 
     def log(self, type, message):
-        print "%s: %s" % (type, message)
+        #print "%s: %s" % (type, message)
         self._log.append((type, message))
     
     def getSongDict(self):
