@@ -18,18 +18,8 @@
 
 
 import os
-import gobject
-import gettext
-
-
-ERROR = ''
-
-try:
-    import win32api
-    import win32gui
-except:
-    ERROR = 'cannot import needed modules'
-
+import ctypes
+user = ctypes.windll.user32
 
 import CurrentSong
 from emesenelib import *
@@ -41,17 +31,19 @@ class Winamp( CurrentSong.CurrentSong ):
         self.winamp = None
         self.isRunning()
         self.currentSong = ''
+        self.template = "Winamp\\0Music\\01\\0{0}\\0%s\\0\\0"
         
     def isPlaying( self ):
-        if self.winamp and win32api.SendMessage(self.winamp, 0x400, 0, 104) != 1:
+        if self.winamp and user.SendMessageW(self.winamp, 0x400, 0, 104) != 1:
             return False
          
         return True
         
     def isRunning( self ):
         try:
-            self.winamp = win32gui.FindWindow('Winamp v1.x', None)
-            return True
+            winampClassName = ctypes.c_wchar_p('Winamp v1.x')
+            self.winamp = user.FindWindowW(winampClassName, None)
+            return self.winamp != 0
         except: 
             return False
 
@@ -59,13 +51,14 @@ class Winamp( CurrentSong.CurrentSong ):
         return self.currentSong
 
     def check( self ):
-        if not self.isRunning(): return False
-        
+        if not self.isRunning(): 
+            self.currentSong = ""
+            return True
         if self.isPlaying():
-            string = 'Winamp\\0Music\\01\\0{0}\\0%s\\0\\0' % \
-                win32gui.GetWindowText( self.winamp ).split(". ",1)[-1] .split(" - Winamp")[0] 
-            newCurrentSong = unicode(string,"Windows-1252")
-            print newCurrentSong
+            st = ctypes.create_unicode_buffer(100)
+            user.GetWindowTextW(self.winamp, st, 100)
+            string = st.value.split(". ",1)[1].split(" - Winamp")[0]
+            newCurrentSong = self.template % string
         else:
             newCurrentSong = ''
 
@@ -86,7 +79,4 @@ class Winamp( CurrentSong.CurrentSong ):
         if os.name != 'nt':
             return ( False, 'This plugin only works on windows systems' )
         
-        if ERROR != '':
-            return ( False, ERROR )
-        
         return ( True, 'Ok' )
