@@ -65,11 +65,13 @@ class MainClass( Plugin.Plugin ):
             self.img.set_pixel_size(10)
             self.button.set_image(self.img)
             self.button.connect("clicked", self.Mcheck , None)
+            self.button.set_tooltip_text(_('Click here to checked your mail'))
             self.Mbox.pack_start(self.button, False, False)
             self.button.show_all()
             
             self.Tbutton = gtk.Button()
             self.Tbutton.connect("clicked", self.Client , None)
+            self.Tbutton.set_tooltip_text(_('Click here to access your mail'))
             self.Mtext = gtk.Label(_("Not checked yet."))
             self.Mtext.set_ellipsize( pango.ELLIPSIZE_END )
             self.Mtext.set_use_underline(True)
